import type { CfSystemChoice, CfAppRouterDeployConfigAnswers } from '../types';
import type { ErrorHandler } from '@sap-ux/inquirer-common';
/**
 * Validates the destination name or input string. If `allowEmptyChoice` is true,
 * the validation will pass immediately. Otherwise, the input will be validated
 * against rules (non-empty, valid characters, length check).
 *
 * @param {string} input - The destination name or input string to validate.
 * @param {boolean} allowEmptyChoice - Whether to allow an empty input as a valid choice.
 * @returns {boolean|string} `true` if the input is valid or empty choices are allowed, otherwise an error message.
 */
export declare function validateDestinationQuestion(input: string | CfSystemChoice, allowEmptyChoice?: boolean): boolean | string;
/**
 * Validates the provided MTA path.
 *
 * @param {string} input - The input string representing the MTA path to validate.
 * @returns {boolean|string} - Returns `true` if the path is valid, or an error message if the path is invalid or does not exist.
 */
export declare function validateMtaPath(input: string): boolean | string;
/**
 * Validates the provided MTA ID.
 *
 * This function performs the following checks:
 * - Ensures the input is a non-empty string.
 * - Validates the input against a regex pattern.
 * - Checks if the MTA ID already exists in the specified path.
 *
 * @param {string} input - The MTA ID to validate.
 * @param {CfAppRouterDeployConfigAnswers} previousAnswers - The previous answers, containing the MTA path.
 * @returns {boolean|string} - Returns true if the MTA ID is valid, or an error message if validation fails.
 */
export declare function validateMtaId(input: string, previousAnswers: CfAppRouterDeployConfigAnswers): boolean | string;
/**
 * Validates the ABAP service choice and provides error handling.
 *
 * @param {string} choice - The selected choice for the ABAP service.
 * @param {ErrorHandler} errorHandler - An instance of an error handler.
 * @returns {string | boolean} - Returns `true` if the choice is valid.
 */
export declare function validateAbapService(choice: string, errorHandler: ErrorHandler): string | boolean;
//# sourceMappingURL=validators.d.ts.map